@@ -85,6 +85,6 @@ class KustoClient(_KustoClientBase):
                     response_text = await response.text()
                 except Exception:
                     response_text = None
-                self._handle_http_error(e, endpoint, payload, response, response_json, response_text)
+                self._handle_http_error(e, endpoint, payload, response, response.status, response_json, response_text)
 
             return self._kusto_parse_by_endpoint(endpoint, response_json)
