@@ -1,3 +1,5 @@
+# Copyright (c) Microsoft Corporation.
+# Licensed under the MIT License
 from enum import Enum
 
 
@@ -17,3 +19,5 @@ class DataFormat(Enum):
     MULTIJSON = "multijson"
     ORC = "orc"
     TSVE = "tsve"
+    RAW = "raw"
+    W3CLOGFILE = "w3clogfile"
